@@ -32,10 +32,8 @@ def test_SineWaveLink():
     exp_mod_out = [3.9477019656331063, 4.268437351642151, 4.204589086020441,
                    3.8476310228828132, 3.7089682798878445]
     assert np.allclose(modellink_obj.call_model(
-                        1, par_dict, sorted(modellink_obj._data_idx)),
-                       exp_mod_out)
+        1, par_dict, sorted(modellink_obj._data_idx)), exp_mod_out)
 
     # Retrieve model discrepancy variance
     assert np.allclose(modellink_obj.get_md_var(
-                        1, par_dict, modellink_obj._data_idx),
-                       [0.01, 0.01, 0.01, 0.01, 0.01])
+        1, par_dict, modellink_obj._data_idx), [0.01, 0.01, 0.01, 0.01, 0.01])
